@@ -19,7 +19,7 @@ my $_process_args = sub {
 };
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Class::Tiny;
 use parent qw( LINQ::FieldSet );
@@ -45,7 +45,7 @@ sub _known_parameter_names {
 		'cmp'     => 1,
 		'numeric' => 0,
 		'string'  => 0,
-		'not'     => 0,
+		'nix'     => 0,
 		'nocase'  => 0,
 	);
 } #/ sub _known_parameter_names
@@ -76,72 +76,63 @@ sub _build_coderef {
 	};
 } #/ sub _build_coderef
 
-my %templates = (
-	'numeric ==' => '%s == %s',
-	'numeric !=' => '%s != %s',
-	'numeric >'  => '%s >  %s',
-	'numeric >=' => '%s >= %s',
-	'numeric <'  => '%s <  %s',
-	'numeric <=' => '%s <= %s',
-	'string =='  => '%s eq %s',
-	'string !='  => '%s ne %s',
-	'string >'   => '%s gt %s',
-	'string >='  => '%s ge %s',
-	'string <'   => '%s lt %s',
-	'string <='  => '%s le %s',
-	'null =='    => 'defined( %s )',
-);
-
-my $_like_to_regexp = sub {
-	my ( $like, $ci ) = @_;
-	my $re      = '';
-	my %anchors = (
-		start => substr( $like, 0,  1 ) ne '%',
-		end   => substr( $like, -1, 1 ) ne '%',
+{
+	my %makers = (
+		'is'       => '_make_is_check',
+		'in'       => '_make_in_check',
+		'like'     => '_make_like_check',
+		'match'    => '_make_match_check',
 	);
-	my @parts = split qr{(\\*[.%])}, $like;
-	for my $p ( @parts ) {
-		next unless length $p;
-		my $backslash_count =()= $p =~ m{(\\)}g;
-		my $wild_count      =()= $p =~ m{([%.])}g;
-		if ( $wild_count ) {
-			if ( $backslash_count && $backslash_count % 2 ) {
-				my $last = substr( $p, -2, 2, '' );
-				$p =~ s{\\\\}{\\};
-				$re .= quotemeta( $p . substr( $last, -1, 1 ) );
-			}
-			elsif ( $backslash_count ) {
-				my $last = substr( $p, -1, 1, '' );
-				$p =~ s{\\\\}{\\};
-				$re .= quotemeta( $p ) . ( $last eq '%' ? '.*' : '.' );
-			}
-			else {
-				$re .= $p eq '%' ? '.*' : '.';
-			}
-		} #/ if ( $wild_count )
-		else {
-			$p =~ s{\\(.)}{$1}g;
-			$re .= quotemeta( $p );
-		}
-	} #/ for my $p ( @parts )
-	
-	substr( $re, 0, 0, '\A' ) if $anchors{start};
-	$re .= '\z'               if $anchors{end};
-	
-	$ci ? qr/$re/i : qr/$re/;
-};
 
-sub _make_check {
-	my ( $self, $field ) = ( shift, @_ );
-	my $getter = $field->getter;
-	
-	if ( exists $field->params->{is} ) {
-		for ( qw/ like in match / ) {
+	sub _make_check {
+		my ( $self, $field ) = ( shift, @_ );
+		
+		my @found;
+		for my $key ( sort keys %makers ) {
+			push @found, $key if exists $field->params->{$key};
+		}
+		
+		if ( @found > 1 ) {
+			my $params = join q[, ], map "-$_", @found;
 			LINQ::Util::Internal::throw(
 				"CallerError",
-				message => "Cannot use '-is' and '-$_' together",
-			) if $field->params->{$_};
+				message => "Multiple conflicting assertions ($params) found for field '@{[ $field->name ]}'",
+			);
 		}
+		
+		if ( @found == 0 ) {
+			LINQ::Util::Internal::throw(
+				"CallerError",
+				message => "No assertions found for field '@{[ $field->name ]}'",
+			);
+		}
+		
+		my $method = $makers{ $found[0] };
+		return $self->$method( $field );
+	}
+}
+
+{
+	my %templates = (
+		'numeric ==' => '%s == %s',
+		'numeric !=' => '%s != %s',
+		'numeric >'  => '%s >  %s',
+		'numeric >=' => '%s >= %s',
+		'numeric <'  => '%s <  %s',
+		'numeric <=' => '%s <= %s',
+		'string =='  => '%s eq %s',
+		'string !='  => '%s ne %s',
+		'string >'   => '%s gt %s',
+		'string >='  => '%s ge %s',
+		'string <'   => '%s lt %s',
+		'string <='  => '%s le %s',
+		'null =='    => 'defined( %s )',
+	);
+	
+	sub _make_is_check {
+		my ( $self, $field ) = ( shift, @_ );
+		my $getter = $field->getter;
+		
 		my $expected = $field->params->{is};
 		my $cmp      = $field->params->{cmp} || "==";
 		my $type =
@@ -182,56 +173,92 @@ sub _make_check {
 			);
 		} #/ else [ if ( $type eq 'null' )]
 		
-		if ( $field->params->{not} ) {
+		if ( $field->params->{nix} ) {
 			$guts = "not( $guts )";
 		}
 		
 		no warnings qw( uninitialized );
 		return eval "sub { $guts }";
-	} #/ if ( exists $field->params...)
+	}
+}
+
+sub _make_in_check {
+	my ( $self, $field ) = ( shift, @_ );
+	my $getter = $field->getter;
+	my @expected = @{ $field->params->{in} };
 	
-	if ( exists $field->params->{in} ) {
-		for ( qw/ is cmp numeric string like match / ) {
-			LINQ::Util::Internal::throw(
-				"CallerError",
-				message => "Cannot use '-in' and '-$_' together",
-			) if $field->params->{$_};
-		}
-		
-		my @expected = @{ $field->params->{in} };
-		
-		if ( $field->params->{not} ) {
-			return sub {
-				my $value = $getter->( $_ );
-				for my $expected ( @expected ) {
-					return !!0 if $value eq $expected;
-				}
-				return !!1;
-			};
-		}
-		else {
-			return sub {
-				my $value = $getter->( $_ );
-				for my $expected ( @expected ) {
-					return !!1 if $value eq $expected;
-				}
-				return !!0;
-			};
-		}
-	} #/ if ( exists $field->params...)
+	my $nix = ! $field->params->{nix};
 	
-	if ( exists $field->params->{like} ) {
-		for ( qw/ is cmp numeric string in match / ) {
-			LINQ::Util::Internal::throw(
-				"CallerError",
-				message => "Cannot use '-like' and '-$_' together",
-			) if $field->params->{$_};
-		}
+	if ( $field->params->{nocase} ) {
+		return sub {
+			my $value = lc $getter->( $_ );
+			for my $expected ( @expected ) {
+				return !!$nix if $value eq lc $expected;
+			}
+			return !$nix;
+		};
+	}
+	else {
+		return sub {
+			my $value = $getter->( $_ );
+			for my $expected ( @expected ) {
+				return !!$nix if $value eq $expected;
+			}
+			return !$nix;
+		};
+	}
+}
+
+{
+	my $_like_to_regexp = sub {
+		my ( $like, $ci ) = @_;
+		my $re      = '';
+		my %anchors = (
+			start => substr( $like, 0,  1 ) ne '%',
+			end   => substr( $like, -1, 1 ) ne '%',
+		);
+		my @parts = split qr{(\\*[.%])}, $like;
+		for my $p ( @parts ) {
+			next unless length $p;
+			my $backslash_count =()= $p =~ m{(\\)}g;
+			my $wild_count      =()= $p =~ m{([%.])}g;
+			if ( $wild_count ) {
+				if ( $backslash_count && $backslash_count % 2 ) {
+					my $last = substr( $p, -2, 2, '' );
+					$p =~ s{\\\\}{\\};
+					$re .= quotemeta( $p . substr( $last, -1, 1 ) );
+				}
+				elsif ( $backslash_count ) {
+					my $last = substr( $p, -1, 1, '' );
+					$p =~ s{\\\\}{\\};
+					$re .= quotemeta( $p ) . ( $last eq '%' ? '.*' : '.' );
+				}
+				else {
+					$re .= $p eq '%' ? '.*' : '.';
+				}
+			} #/ if ( $wild_count )
+			else {
+				$p =~ s{\\(.)}{$1}g;
+				$re .= quotemeta( $p );
+			}
+		} #/ for my $p ( @parts )
+		
+		substr( $re, 0, 0, '\A' ) if $anchors{start};
+		$re .= '\z'               if $anchors{end};
+		
+		$ci ? qr/$re/i : qr/$re/;
+	};
+
+	sub _make_like_check {
+		my ( $self, $field ) = ( shift, @_ );
+		my $getter = $field->getter;
+		
 		my $match = $_like_to_regexp->(
 			$field->params->{like},
 			$field->params->{nocase},
 		);
-		if ( $field->params->{not} ) {
+		
+		if ( $field->params->{nix} ) {
 			return sub {
 				my $value = $getter->( $_ );
 				$value !~ $match;
@@ -243,36 +270,30 @@ sub _make_check {
 				$value =~ $match;
 			};
 		}
-	} #/ if ( exists $field->params...)
+	}
+}
+
+sub _make_match_check {
+	my ( $self, $field ) = ( shift, @_ );
+	my $getter = $field->getter;
 	
-	if ( exists $field->params->{match} ) {
-		for ( qw/ is cmp numeric string in like / ) {
-			LINQ::Util::Internal::throw(
-				"CallerError",
-				message => "Cannot use '-match' and '-$_' together",
-			) if $field->params->{$_};
-		}
-		my $match = $field->params->{match};
-		require match::simple;
-		if ( $field->params->{not} ) {
-			return sub {
-				my $value = $getter->( $_ );
-				not match::simple::match( $value, $match );
-			};
-		}
-		else {
-			return sub {
-				my $value = $getter->( $_ );
-				match::simple::match( $value, $match );
-			};
-		}
-	} #/ if ( exists $field->params...)
+	my $match = $field->params->{match};
 	
-	LINQ::Util::Internal::throw(
-		"CallerError",
-		message => "Expected '-is', '-in', or '-like'",
-	) if $field->params->{$_};
-} #/ sub _make_check
+	require match::simple;
+	
+	if ( $field->params->{nix} ) {
+		return sub {
+			my $value = $getter->( $_ );
+			not match::simple::match( $value, $match );
+		};
+	}
+	else {
+		return sub {
+			my $value = $getter->( $_ );
+			match::simple::match( $value, $match );
+		};
+	}
+}
 
 sub not {
 	my ( $self ) = ( shift );
@@ -300,7 +321,7 @@ sub or {
 package LINQ::FieldSet::Assertion::Combination;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Role::Tiny;
 requires( qw/ left right _build_coderef / );
@@ -336,7 +357,7 @@ sub or {
 package LINQ::FieldSet::Assertion::NOT;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Class::Tiny qw( left );
 use Role::Tiny::With ();
@@ -371,7 +392,7 @@ sub right {
 package LINQ::FieldSet::Assertion::AND;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Class::Tiny qw( left right );
 use Role::Tiny::With ();
@@ -395,7 +416,7 @@ sub _build_coderef {
 package LINQ::FieldSet::Assertion::OR;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Class::Tiny qw( left right );
 use Role::Tiny::With ();
@@ -417,3 +438,117 @@ sub _build_coderef {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+LINQ::FieldSet::Assertion - represents an SQL-WHERE-like assertion/check
+
+=head1 DESCRIPTION
+
+LINQ::FieldSet::Assertion is a subclass of L<LINQ::FieldSet>.
+
+This is used internally by LINQ and you probably don't need to know about it
+unless you're writing very specific extensions for LINQ. The end user
+interface is the C<check_fields> function in L<LINQ::Util>.
+
+=head1 CONSTRUCTOR
+
+=over
+
+=item C<< new( ARGSLIST ) >>
+
+Constructs a fieldset from a list of fields like:
+
+  'LINQ::FieldSet::Assertion'->new(
+    'field1', -param1 => 'value1', -param2,
+    'field2', -param1 => 'value2',
+  );
+
+Allowed parameters are:
+C<< -is >> (followed by a value),
+C<< -in >> (followed by a value),
+C<< -like >> (followed by a value),
+C<< -match >> (followed by a value),
+C<< -cmp >> (followed by a value),
+C<< -numeric >> (no value),
+C<< -string >> (no value),
+C<< -not >> (no value), and
+C<< -nocase >> (no value).
+
+=back
+
+=begin trustme
+
+=item BUILD
+
+=end trustme 
+
+=head1 METHODS
+
+=over
+
+=item C<< and( OTHER ) >>
+
+Return a LINQ::FieldSet::Assertion::AND object which is a conjunction of this
+assertion and another assertion.
+
+=item C<< or( OTHER ) >>
+
+Return a LINQ::FieldSet::Assertion::OR object which is an inclusive disjunction
+of this assertion and another assertion.
+
+=item C<not>
+
+Return a LINQ::FieldSet::Assertion::NOT object which is the negation of this
+assertion.
+
+=item C<coderef>
+
+Gets a coderef for this assertion; the coderef operates on C<< $_ >>.
+
+=back
+
+The LINQ::FieldSet::Assertion::{AND,OR,NOT} classes are lightweight classes
+which also implement the C<and>, C<or>, C<not>, and C<coderef> methods, and
+have the same overloading as LINQ::FieldSet::Assertion, but do not inherit
+from it.
+
+=head1 OVERLOADING
+
+This class overloads
+C<< & >> to call the C<< and >> method;
+C<< | >> to call the C<< or >> method;
+C<< ~ >> to call the C<< not >> method; and
+C<< &{} >> to call the C<< coderef >> method.
+
+=head1 BUGS
+
+Please report any bugs to
+L<http://rt.cpan.org/Dist/Display.html?Queue=LINQ>.
+
+=head1 SEE ALSO
+
+L<LINQ::FieldSet>, L<LINQ::Util>.
+
+=head1 AUTHOR
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2021 by Toby Inkster.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
