@@ -103,7 +103,7 @@ if ( $] < 5.010000 ) {
 package LINQ::Iterator;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Role::Tiny::With     ();
 use LINQ::Util::Internal ();
@@ -176,3 +176,67 @@ sub to_iterator {
 } #/ sub to_iterator
 
 1;
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+LINQ::Iterator - a LINQ collection with an iterator backend
+
+=head1 SYNOPSIS
+
+  use LINQ qw( LINQ );
+  use LINQ::Iterator;
+  
+  my $linq  = LINQ( sub { ... } );
+  
+  # Same:
+  my $linq  = 'LINQ::Iterator'->new( sub { ... } );
+
+=head1 METHODS
+
+LINQ::Iterator supports all the methods defined in L<LINQ::Collection>.
+
+=begin trustme
+
+=item new
+
+=item element_at
+
+=item to_list
+
+=item to_iterator
+
+=end trustme
+
+=head1 BUGS
+
+Please report any bugs to
+L<http://rt.cpan.org/Dist/Display.html?Queue=LINQ>.
+
+=head1 SEE ALSO
+
+L<LINQ>, L<LINQ::Collection>.
+
+L<https://en.wikipedia.org/wiki/Language_Integrated_Query>
+
+=head1 AUTHOR
+
+Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2021 by Toby Inkster.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
