@@ -5,7 +5,7 @@ use warnings;
 package LINQ::Util;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_007';
+our $VERSION   = '0.000_008';
 
 use Exporter::Shiny qw( fields check_fields );
 
@@ -21,6 +21,8 @@ sub check_fields {
 
 1;
 
+__END__
+
 =pod
 
 =encoding utf-8
@@ -47,7 +49,8 @@ LINQ::Util - useful utilities to make working with LINQ collections easier
   for ( $name_and_dept->to_list ) {
     printf( "Hi, I'm %s from %s\n", $_->name, $_->dept );
   }
-head1 DESCRIPTION
+
+=head1 DESCRIPTION
 
 LINQ::Util provides a collection of auxiliary functions to make working with
 LINQ collections a little more intuitive and perhaps avoid passing a bunch of
@@ -125,8 +128,8 @@ or string comparison, but if you need to specify, you can:
   $people
     ->where( check_fields( 'phone', -is => '012345679', -string );
   
-   $people
-      ->where( check_fields( 'age', -is => '33', -numeric );
+  $people
+    ->where( check_fields( 'age', -is => '33', -numeric );
 
 String comparisons can be made case-insensitive:
 
@@ -139,10 +142,10 @@ always stringy and case-sensitive.
   $people
     ->where( check_fields( 'name', -in => ['Alice', 'Bob'] ) );
 
-You can invert any comparison using C<< -not >>.
+You can invert any comparison using C<< -nix >>.
 
   $people
-    ->where( check_fields( 'name', -not, -in => ['Alice', 'Bob'] ) );
+    ->where( check_fields( 'name', -nix, -in => ['Alice', 'Bob'] ) );
 
 You can perform more complex matches using L<match::simple>:
 
@@ -160,7 +163,7 @@ conditions.
   $people
     ->where( check_fields(
       'name',       -is => 'Bob',
-      'age',  -not, -is => 33,
+      'age',  -nix, -is => 33,
     ) );
 
 You can invert a whole C<< check_fields() >> using the C<< not >> method:
